@@ -1,11 +1,8 @@
 from func_timeout import func_timeout, FunctionTimedOut
-from numpy import array as np_array
-from multiprocessing.pool import ThreadPool
 
 from pandas import DataFrame as PandasDF, Series as PandasSeries, concat
 from sklearn.cluster import KMeans as SklearnKMeans
 from sklearn.metrics import silhouette_score
-from sklearn.metrics import pairwise_distances
 
 from pyspark.sql import functions as f
 from pyspark.sql.types import DoubleType, StringType
